@@ -43,7 +43,11 @@ def between(name: str, low: int, high: int) -> tuple[str, Signature]:
     """Between constraint"""
     return (name, op.between(low, high))
 
+def in_(values: list[Any]):
+    """In VALUES"""
+    return this.in_(values)
+
 
 this = op
 
-__all__ = ["eq", "lt", "le", "gt", "ge", "ne", "like", "between", "this"]
+__all__ = ["eq", "lt", "le", "gt", "ge", "ne", "like", "between", "this", 'in_']
